__version__ = "0.1.2"
__git_commiter_name__ = "Arnon Yaari"
__git_commiter_email__ = "arnony@infinidat.com"
__git_branch__ = '(detached from v0.1.2)'
__git_remote_tracking_branch__ = '(No remote tracking)'
__git_remote_url__ = '(Not remote tracking)'
__git_head_hash__ = '62f7605210b77b7d8816ce74a5aca31ea9af1afd'
__git_head_subject__ = 'Finished release v0.1.2.'
__git_head_message__ = ''
__git_dirty_diff__ = ''